==> haskell-securemem-0.1.10-58-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.10
id: securemem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY
key: securemem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
abi: 726f1e349d888d9edb37dd1a6ee8beb4
exposed: True
exposed-modules:
    Data.SecureMem
import-dirs: /usr/lib/ghc-8.6.5/site-local/securemem-0.1.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/securemem-0.1.10
hs-libraries: HSsecuremem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 ghc-prim-0.5.3
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-securemem-0.1.10-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-securemem.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: securemem
version: 0.1.10
id: securemem-0.1.10-L4TfLmHXcEx8teV0rzp6zE
key: securemem-0.1.10-L4TfLmHXcEx8teV0rzp6zE
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-securemem
synopsis: abstraction to an auto scrubbing and const time eq, memory chunk.
description:
    SecureMem is similar to ByteString, except that it provides a memory chunk that
    will be auto-scrubbed after it run out of scope.
category: Data
abi: 03476ef08e6c2aa74c0b47eb21daf029
exposed: True
exposed-modules:
    Data.SecureMem
import-dirs: /usr/lib/ghc-8.6.5/site-local/securemem-0.1.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/securemem-0.1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/securemem-0.1.10
hs-libraries: HSsecuremem-0.1.10-L4TfLmHXcEx8teV0rzp6zE
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 ghc-prim-0.5.3
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
haddock-interfaces: /usr/share/doc/haskell-securemem/html/securemem.haddock
haddock-html: /usr/share/doc/haskell-securemem/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
